@@ -139,8 +139,8 @@ def select_features(X, y, metric, metric_name = '', N = 30, feature_names = None
     idx = np.argsort(metric)[::-1][:N] # idx = np.where(F > 30)[0] # np.where(pval < 0.00001)
     
     if (feature_names):
-        print('Important feature indices: ', idx)
-        print('Important feature names: ', feature_names[idx])
+        print('Top ' + str(N) + ' important feature indices: ', idx)
+        print('Top ' + str(N) + ' important feature names: ', np.array(feature_names)[np.array(idx)])
 
     X_M = X[:,idx]
     unsupervised_dimension_reductions(X_M, y, set(y))
